@@ -15,7 +15,8 @@ from tpm2_pytss import *
 
 from tpm2_pytss.internal.utils import is_bug_fixed
 
-from .TSS2_BaseTest import TpmSimulator, TSS2_BaseTest
+from .TSS2_BaseTest import TpmSimulator
+from tpm2_pytss.TSS2_Exception import TSS2_Exception
 
 pytestmark = pytest.mark.skipif(
     "tpm2_pytss.FAPI" not in sys.modules, reason="FAPI Not Detected"
@@ -37,6 +38,8 @@ def fapi_config_ecc(simulator):
         tcti=simulator.tcti_name_conf,
         ek_cert_less="yes",
         profile_name="P_ECCP256SHA256",
+        firmware_log_file="/dev/null",
+        ima_log_file="/dev/null",
     ) as fapi_config:
         yield fapi_config
 
@@ -48,6 +51,8 @@ def fapi_config_rsa(simulator):
         tcti=simulator.tcti_name_conf,
         ek_cert_less="yes",
         profile_name="P_RSA2048SHA256",
+        firmware_log_file="/dev/null",
+        ima_log_file="/dev/null",
     ) as fapi_config:
         yield fapi_config
 
@@ -447,7 +452,7 @@ class Common:
         assert info_json["attest"]["type"] == "ATTEST_QUOTE"
         assert type(signature) is bytes
         pcr_log_json = json.loads(pcr_log)
-        assert pcr_log_json == []
+        assert type(pcr_log_json) == list
         assert certificate == ""
 
         # TODO verify via openssl
@@ -514,8 +519,9 @@ class Common:
 
     def test_pcr_read(self):
         value, log = self.fapi.pcr_read(7)
+        log_json = json.loads(log)
         assert value == b"\0" * 32
-        assert log == "[\n]"
+        assert type(log_json) == list
 
     def test_pcr_extend_read(self):
         index = 16
@@ -776,6 +782,12 @@ class Common:
         # use key for signing: success
         self.fapi.sign(path=key_path, digest=b"\x11" * 32)
 
+        # unset signing callback, should fail
+        self.fapi.set_sign_callback(callback=None)
+
+        with pytest.raises(TSS2_Exception):
+            self.fapi.sign(path=key_path, digest=b"\x11" * 32)
+
     def test_policy_branched(self):
         pcr_index = 15
         pcr_data = b"ABCDEF"
@@ -880,6 +892,15 @@ class Common:
         nv_data, _ = self.fapi.nv_read(nv_path)
         assert nv_data == b"Hello World"
 
+        # test without a callback set
+        if not is_bug_fixed(fixed_in="3.1", backports=["2.4.3", "3.0.1", "3.1.0"]):
+            # skip tests as theirs a bug
+            return
+
+        self.fapi.set_branch_callback(callback=None)
+        with pytest.raises(TSS2_Exception):
+            self.fapi.nv_read(nv_path)
+
         # clean up
         self.fapi.delete(path=nv_path)
 
@@ -934,6 +955,12 @@ class Common:
         # use key for signing: success
         self.fapi.sign(path=key_path, digest=b"\x11" * 32)
 
+        # set policy Action callback to NULL
+        self.fapi.set_policy_action_callback(callback=None)
+
+        with pytest.raises(TSS2_Exception):
+            self.fapi.sign(path=key_path, digest=b"\x11" * 32)
+
 
 @pytest.mark.usefixtures("init_fapi_ecc")
 class TestFapiECC(Common):
